function [r, r0] = acf( s, m )
%[r, r0] = acf( s, m )
% Auto Correlation Function
% Uses fix window length for all time-lags
% Normalized to r(1)=1.0
%
%	s - input segment
%	m - maximum time lag in samples
%
%	r - m+1 length ACF vector
%	r0 - power of windowed frame
%
%NOTE: m must complete  0 < m+1 < length(s)  constraint

s = s(:);

% auto correlation
col = flipud( s(1:m+1) );
row = s( m+1:end );
r = rtmult( col, row, row );

% power of windowed frame
r0 = r(1) / length( row );

% scaling to normal
sc = 1.0 / max( r(1), eps );
r = r * sc;
